#!/bin/bash
set -e

# download and install dropshell

# Check if running as root
if [ "$EUID" -ne 0 ]; then
    echo "Please run this script as root (use sudo)"
    exit 1
fi

# 1. Determine architecture
# ----------------------------------------------------------------------------- 

ARCH=$(uname -m)
if [[ "$ARCH" == "x86_64" ]]; then
    BIN=dropshell.amd64
elif [[ "$ARCH" == "aarch64" || "$ARCH" == "arm64" ]]; then
    BIN=dropshell.arm64
else
    echo "Unsupported architecture: $ARCH" >&2
    exit 1
fi


# 2. Download the appropriate binary to a temp directory
# -----------------------------------------------------------------------------
TMPDIR=$(mktemp -d)
trap 'rm -rf "$TMPDIR"' EXIT
URL="https://gitea.jde.nz/public/dropshell/releases/download/latest/$BIN"
echo "Downloading $BIN from $URL..."

curl -fsSL -o "$TMPDIR/dropshell" "$URL"

if [ ! -f "$TMPDIR/dropshell" ]; then
    echo "Failed to download dropshell" >&2
    exit 1
fi

chmod +x "$TMPDIR/dropshell"

cp "$TMPDIR/dropshell" /usr/local/bin/dropshell
if [ -f /usr/local/bin/ds ]; then
    rm -f /usr/local/bin/ds
fi
ln -s /usr/local/bin/dropshell /usr/local/bin/ds
rm -rf "$TMPDIR"

echo "dropshell installed successfully to /usr/local/bin/dropshell"

